@@ -7,10 +7,10 @@ from pybsc import nsplit
 from pybsc import save_json
 from pybsc.video_utils import extract_target_frame_from_timestamp
 
+from labanotation.algorithm import merge_keyframe_indices
 from labanotation.io import read_from_labanotation_suite
 from labanotation.labanotation_utils import arrange_labanotations
 from labanotation.labanotation_utils import calculate_unfiltered_labanotations
-from labanotation.labanotation_utils import calculate_z_axis
 from labanotation.labanotation_utils import extract_target_labanotations
 from labanotation.labanotation_utils import laban2str2
 from labanotation import parallel_energy
@@ -26,7 +26,8 @@ def get_labanotation_results(csv_filepath,
                              base_rotation_style='update',
                              save_laban_image=True,
                              return_full=False,
-                             return_savefilepaths=False):
+                             return_savefilepaths=False,
+                             z_axis=None):
     output_path = Path(output_path)
     csv_filepath = Path(csv_filepath)
     save_filepaths = []
@@ -34,9 +35,6 @@ def get_labanotation_results(csv_filepath,
     joint_positions_dict, timestamps = read_from_labanotation_suite(
         csv_filepath)
 
-    z_axis = calculate_z_axis(joint_positions_dict['shoulder_left'],
-                              joint_positions_dict['shoulder_right'],
-                              joint_positions_dict['spine_navel'],)
     lines = calculate_unfiltered_labanotations(
         joint_positions_dict,
         base_rotation_style=base_rotation_style,
@@ -90,11 +88,15 @@ def get_labanotation_results(csv_filepath,
         joint_positions_dict['wrist_right'],
         gauss_window_size=gauss_window_size,
         gauss_sigma=gauss_sigma)
+    wrist_right_keyframe_indices = merge_keyframe_indices(
+        [wrist_right_keyframe_indices], n=len(timestamps))
     wrist_left_keyframe_indices, left_energy, _, _ = total_energy(
         timestamps,
         joint_positions_dict['wrist_left'],
         gauss_window_size=gauss_window_size,
         gauss_sigma=gauss_sigma)
+    wrist_left_keyframe_indices = merge_keyframe_indices(
+        [wrist_left_keyframe_indices], n=len(timestamps))
 
     keyframe_dict = {}
     for index in keyframe_indices:
